@@ -300,7 +300,7 @@ def get_y(y_df, prediction_type):
     if prediction_type == 'sur':
         col_event = y_df.columns[0]
         col_time = y_df.columns[1]
-        y = np.empty(dtype=[(col_event, np.bool), (col_time, np.float64)],
+        y = np.empty(dtype=[(col_event, bool), (col_time, np.float64)],
                     shape=y_df.shape[0])
         y[col_event] = (y_df[col_event] == 1).values
         y[col_time] = y_df[col_time].values
@@ -614,7 +614,7 @@ def check_data_config(config_file):
     verify data configuration file
     """
     with open(config_file) as config_fh:
-        data_config = yaml.load(config_fh)
+        data_config = yaml.load(config_fh, Loader=yaml.FullLoader)
 
     required_fields = {'project_name', 'data_directory', 'train_data_directory', 'target_view',
                        'target_label', 'data'}
@@ -648,7 +648,7 @@ def create_dataset(config_file, output_run):
     print(f'data config file: {config_file}')
     check_data_config(config_file)
     with open(config_file) as config_fh:
-        data_config = yaml.load(config_fh)
+        data_config = yaml.load(config_fh, Loader=yaml.FullLoader)
         data_root = data_config['data_directory']
         if not os.path.isabs(data_root):
             # relative to the data config file
@@ -662,7 +662,7 @@ def create_dataset(config_file, output_run):
 
 def check_run_config(run_config_file, n_train_sample, prediction_type):
     with open(run_config_file) as config_fh:
-        run_config = yaml.load(config_fh)
+        run_config = yaml.load(config_fh, Loader=yaml.FullLoader)
         if not 'n_jobs' in run_config:
             # assume running on a node with 4 cpus
             run_config['n_jobs'] = 4
